This function is used internally, and input checking is not performed here, only in the context where it is used. Using it directly is not recommended.
.adjust_next_gen(next_gen, susc_pop)A numeric vector of the adjusted next generation offspring.
A numeric vector of next generation offspring.
The susceptible population size; A number coercible to integer.