Learn R Programming

epichains (version 0.1.1)

.check_generation_time_valid: Check if the generation_time argument is specified as a function

Description

Check if the generation_time argument is specified as a function

Usage

.check_generation_time_valid(generation_time)

Arguments

generation_time

The generation time function; the name of a user-defined named or anonymous function with only one argument n, representing the number of generation times to sample.