Learn R Programming

epichains (version 0.1.1)

.geom_length_ll: Log-likelihood of the length of chains with geometric offspring distribution

Description

Log-likelihood of the length of chains with geometric offspring distribution

Usage

.geom_length_ll(x, prob)

Value

A numeric vector of log-likelihood values.

Arguments

x

A numeric vector of chain lengths.

prob

The probability of the geometric distribution with mean 1/prob. A single numeric value between 0 and 1.

Author

Sebastian Funk James M. Azam