Samples the length of a transmission chain where each individual element is observed with binomial probability with parameters n (number of successes) and p (success probability)
.rgen_length(n, x, prob)A numeric vector of the sampled chain lengths.
The number of samples to generate. Must be a positive integer.
A numeric vector of the observed chain lengths.
The probability of observation. A numeric between 0 and 1.
Sebastian Funk