Learn R Programming

epichains (version 0.1.1)

covid19_sa: COVID-19 Data Repository for South Africa

Description

An aggregated subset of the COVID-19 Data Repository for South Africa created, maintained and hosted by Data Science for Social Impact research group, led by Dr. Vukosi Marivate.

Usage

covid19_sa

Arguments

Format

covid19_sa

A data frame with 19 rows and 2 columns:

date

Date case was reported

cases

Number of cases

Details

The data is originally provided as a linelist but has been subsetted and cleaned in data-raw/covid19_sa.R.