powered by
Log-likelihood of the length of chains with geometric offspring distribution
.geom_length_ll(x, prob)
A numeric vector of log-likelihood values.
A numeric vector of chain lengths.
The probability of the geometric distribution with mean 1/prob. A single numeric value between 0 and 1.
1/prob
Sebastian Funk James M. Azam