.pois_length_ll: Log-likelihood of the length of chains with Poisson offspring distribution
Description
Log-likelihood of the length of chains with Poisson offspring distribution
Usage
.pois_length_ll(x, lambda)
Value
A numeric vector of log-likelihood values.
Arguments
- x
A numeric vector of chain lengths.
- lambda
The rate of the Poisson distribution. A single numeric value.
Must be positive.
Author
Sebastian Funk James M. Azam